"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const parseCheckBoxDescriptor_1 = require("./parseCheckBoxDescriptor");
const chai_1 = require("chai");
const parseCheckListDescriptor_1 = require("./parseCheckListDescriptor");
const parseTextFieldDescriptor_1 = require("./parseTextFieldDescriptor");
const parseTextAreaDescriptor_1 = require("./parseTextAreaDescriptor");
const parseNumberDescriptor_1 = require("./parseNumberDescriptor");
const parseDateTimeDescriptor_1 = require("./parseDateTimeDescriptor");
describe("camunda form descriptors parsing", () => {
    it("parseTextAreaDescriptor", () => {
        const descriptor = {
            "label": "Text",
            "type": "textarea",
            "layout": {
                "row": "Row_04gdzdy",
                "columns": null
            },
            "id": "Field_0mzzvyb",
            "key": "text",
            "disabled": false
        };
        const props = (0, parseTextAreaDescriptor_1.parseTextAreaDescriptor)(descriptor);
        (0, chai_1.expect)(props).to.deep.eq({
            source: 'text',
            label: 'Text',
            helperText: undefined,
            defaultValue: undefined,
            readOnly: false,
            disabled: false,
            validate: []
        });
    });
    it("parseTextFieldDescriptor", () => {
        const descriptor = {
            "label": "To",
            "type": "textfield",
            "layout": {
                "row": "Row_02k62cb",
                "columns": null
            },
            "id": "Field_14nil3w",
            "key": "to",
            "validate": {
                "validationType": "email",
                "required": true
            }
        };
        const props = (0, parseTextFieldDescriptor_1.parseTextFieldDescriptor)(descriptor);
        (0, chai_1.expect)(props).to.deep.eq({
            source: 'to',
            label: 'To',
            helperText: undefined,
            defaultValue: undefined,
            readOnly: false,
            disabled: false,
            validate: []
        });
    });
    it("parseNumberDescriptor", () => {
        const descriptor = {
            "label": "Retries count",
            "type": "number",
            "layout": {
                "row": "Row_18buy6d",
                "columns": null
            },
            "id": "Field_1uw4mqx",
            "key": "retires_number",
            "description": "Count of retries to send an email",
            "defaultValue": 1,
            "increment": "1",
            "validate": {
                "min": 1,
                "max": 5
            }
        };
        const props = (0, parseNumberDescriptor_1.parseNumberDescriptor)(descriptor);
        (0, chai_1.expect)(props).to.deep.eq({
            source: 'retires_number',
            label: 'Retries count',
            helperText: 'Count of retries to send an email',
            defaultValue: 1,
            readOnly: false,
            disabled: false,
            validate: [],
            decimalDigits: 0,
            step: '1'
        });
    });
    it("parseDateTimeDescriptor", () => {
        const descriptor = {
            "dateLabel": "Notification date and time",
            "label": "Date time",
            "type": "datetime",
            "layout": {
                "row": "Row_0v721i9",
                "columns": null
            },
            "id": "Field_1tmvjse",
            "key": "notification_date_time",
            "disallowPassedDates": true,
            "timeInterval": 30,
            "use24h": true
        };
        const props = (0, parseDateTimeDescriptor_1.parseDateTimeDescriptor)(descriptor);
        (0, chai_1.expect)(props).to.deep.eq({
            source: 'notification_date_time',
            label: 'Notification date and time ',
            helperText: undefined,
            readOnly: false,
            disabled: false,
            validate: [],
            disablePast: true,
            minutesStep: 30,
            ampm: false,
            ampmInClock: false
        });
    });
    it("parseCheckBoxDescriptor", () => {
        const descriptor = {
            "label": "Is Claim accepted?",
            "type": "checkbox",
            "id": "Field_1lg64wu",
            "key": "isClaimAccepted",
            "description": "Mark as checked if the Claim must be accepted",
            "layout": {
                "row": "Row_1n2k5bm"
            }
        };
        const props = (0, parseCheckBoxDescriptor_1.parseCheckBoxDescriptor)(descriptor);
        (0, chai_1.expect)(props).to.deep.eq({
            source: 'isClaimAccepted',
            readOnly: false,
            disabled: false,
            defaultChecked: false,
            helperText: 'Mark as checked if the Claim must be accepted',
            label: 'Is Claim accepted?',
            validate: []
        });
    });
    it("parseCheckListDescriptor", () => {
        const descriptor = {
            "values": [
                {
                    "label": "12 hours",
                    "value": "12_hours"
                },
                {
                    "label": "1 day",
                    "value": "1_day"
                },
                {
                    "label": "3 days",
                    "value": "3_days"
                }
            ],
            "label": "Remind after",
            "type": "checklist",
            "layout": {
                "row": "Row_04gdzdt",
                "columns": null
            },
            "id": "Field_1918zkp",
            "key": "remind_after"
        };
        const props = (0, parseCheckListDescriptor_1.parseCheckListDescriptor)(descriptor);
        (0, chai_1.expect)(props).to.deep.eq({
            source: 'remind_after',
            choices: [
                { label: '12 hours', value: '12_hours' },
                { label: '1 day', value: '1_day' },
                { label: '3 days', value: '3_days' }
            ],
            optionText: 'label',
            optionValue: 'value',
            disabled: undefined,
            row: false,
            readOnly: undefined,
            helperText: undefined,
            label: 'Remind after',
            validate: [],
            translateChoice: false
        });
    });
});
//# sourceMappingURL=descriptors.test.js.map